# Table of Contents

<!-- toc -->

- [Integration with other apps](#integration-with-other-apps)
  * [Browser Integration](#browser-integration)
    + [url open](#url-open)
    + [DevTools](#devtools)
    + [Firefox](#firefox)
    + [live preview](#live-preview)
    + [search](#search)
    + [Bookmarks](#bookmarks)
  * [Other Editor](#other-editor)
    + [VS Code](#vs-code)
    + [Helix](#helix)
    + [Xcode](#xcode)
  * [JetBrains](#jetbrains)
  * [Desktop Integration](#desktop-integration)
- [Development environment](#development-environment)
  * [Shell](#shell)
    + [zsh](#zsh)
    + [fish](#fish)
    + [nushell](#nushell)
  * [GUI](#gui)
    + [Avalonia](#avalonia)
    + [Stata](#stata)
  * [Terminal](#terminal)
    + [Kitty](#kitty)
      - [Image](#image)
    + [WezTerm](#wezterm)
    + [Windows Terminal](#windows-terminal)
  * [Infra](#infra)
    + [OpenStack](#openstack)
    + [SonarLint](#sonarlint)
    + [Kafka](#kafka)
    + [Dataform](#dataform)
  * [Cloud](#cloud)
    + [Terraform](#terraform)
    + [Ansible](#ansible)
    + [Kustomize](#kustomize)
    + [AWS](#aws)
      - [S3](#s3)
      - [CloudWatch](#cloudwatch)
    + [Azure](#azure)
    + [Salesforce](#salesforce)
    + [dbt](#dbt)
    + [sdfcli](#sdfcli)
  * [Ethereum](#ethereum)
    + [foundry](#foundry)
  * [Password Manager](#password-manager)
  * [IME](#ime)
    + [Fcitx](#fcitx)
    + [SKK](#skk)
    + [migemo](#migemo)
  * [Battery](#battery)
  * [Audio](#audio)
    + [SuperCollider](#supercollider)
    + [LilyPond](#lilypond)

<!-- tocstop -->

## Integration with other apps

- [Massolari/forem.nvim](https://github.com/Massolari/forem.nvim) ![](https://img.shields.io/github/stars/Massolari/forem.nvim) ![](https://img.shields.io/github/last-commit/Massolari/forem.nvim) ![](https://img.shields.io/github/commit-activity/y/Massolari/forem.nvim)
- [gwatcha/reaper-keys](https://github.com/gwatcha/reaper-keys) ![](https://img.shields.io/github/stars/gwatcha/reaper-keys) ![](https://img.shields.io/github/last-commit/gwatcha/reaper-keys) ![](https://img.shields.io/github/commit-activity/y/gwatcha/reaper-keys)

### Browser Integration

- [lalitmee/browse.nvim](https://github.com/lalitmee/browse.nvim) ![](https://img.shields.io/github/stars/lalitmee/browse.nvim) ![](https://img.shields.io/github/last-commit/lalitmee/browse.nvim) ![](https://img.shields.io/github/commit-activity/y/lalitmee/browse.nvim)
- [psaikido/hupoon.nvim](https://github.com/psaikido/hupoon.nvim) ![](https://img.shields.io/github/stars/psaikido/hupoon.nvim) ![](https://img.shields.io/github/last-commit/psaikido/hupoon.nvim) ![](https://img.shields.io/github/commit-activity/y/psaikido/hupoon.nvim)
- [mochi-sann/Select2Browser.nvim](https://github.com/mochi-sann/Select2Browser.nvim) ![](https://img.shields.io/github/stars/mochi-sann/Select2Browser.nvim) ![](https://img.shields.io/github/last-commit/mochi-sann/Select2Browser.nvim) ![](https://img.shields.io/github/commit-activity/y/mochi-sann/Select2Browser.nvim)
- [andres-lowrie/nvim-search-internet](https://github.com/andres-lowrie/nvim-search-internet) ![](https://img.shields.io/github/stars/andres-lowrie/nvim-search-internet) ![](https://img.shields.io/github/last-commit/andres-lowrie/nvim-search-internet) ![](https://img.shields.io/github/commit-activity/y/andres-lowrie/nvim-search-internet)
- [elentok/open-link.nvim](https://github.com/elentok/open-link.nvim) ![](https://img.shields.io/github/stars/elentok/open-link.nvim) ![](https://img.shields.io/github/last-commit/elentok/open-link.nvim) ![](https://img.shields.io/github/commit-activity/y/elentok/open-link.nvim)
- [z0rzi/open-from-chrome.nvim](https://github.com/z0rzi/open-from-chrome.nvim) ![](https://img.shields.io/github/stars/z0rzi/open-from-chrome.nvim) ![](https://img.shields.io/github/last-commit/z0rzi/open-from-chrome.nvim) ![](https://img.shields.io/github/commit-activity/y/z0rzi/open-from-chrome.nvim)

#### url open

- [sontungexpt/url-open](https://github.com/sontungexpt/url-open) ![](https://img.shields.io/github/stars/sontungexpt/url-open) ![](https://img.shields.io/github/last-commit/sontungexpt/url-open) ![](https://img.shields.io/github/commit-activity/y/sontungexpt/url-open)

#### DevTools

- [carlosrocha/chrome-remote.nvim](https://github.com/carlosrocha/chrome-remote.nvim) ![](https://img.shields.io/github/stars/carlosrocha/chrome-remote.nvim) ![](https://img.shields.io/github/last-commit/carlosrocha/chrome-remote.nvim) ![](https://img.shields.io/github/commit-activity/y/carlosrocha/chrome-remote.nvim)

#### Firefox

- [dawsers/telescope-firefox.nvim](https://github.com/dawsers/telescope-firefox.nvim) ![](https://img.shields.io/github/stars/dawsers/telescope-firefox.nvim) ![](https://img.shields.io/github/last-commit/dawsers/telescope-firefox.nvim) ![](https://img.shields.io/github/commit-activity/y/dawsers/telescope-firefox.nvim)

#### live preview

- [dimchee/prochrome.nvim](https://github.com/dimchee/prochrome.nvim) ![](https://img.shields.io/github/stars/dimchee/prochrome.nvim) ![](https://img.shields.io/github/last-commit/dimchee/prochrome.nvim) ![](https://img.shields.io/github/commit-activity/y/dimchee/prochrome.nvim)

#### search

- [sunjon/telescope-arecibo.nvim](https://github.com/sunjon/telescope-arecibo.nvim) ![](https://img.shields.io/github/stars/sunjon/telescope-arecibo.nvim) ![](https://img.shields.io/github/last-commit/sunjon/telescope-arecibo.nvim) ![](https://img.shields.io/github/commit-activity/y/sunjon/telescope-arecibo.nvim)
- [0ql/google_search.nvim](https://github.com/0ql/google_search.nvim) ![](https://img.shields.io/github/stars/0ql/google_search.nvim) ![](https://img.shields.io/github/last-commit/0ql/google_search.nvim) ![](https://img.shields.io/github/commit-activity/y/0ql/google_search.nvim)
- [dzfrias/gsearch.nvim](https://github.com/dzfrias/gsearch.nvim) ![](https://img.shields.io/github/stars/dzfrias/gsearch.nvim) ![](https://img.shields.io/github/last-commit/dzfrias/gsearch.nvim) ![](https://img.shields.io/github/commit-activity/y/dzfrias/gsearch.nvim)
- [gudjonragnar/searcher.nvim](https://github.com/gudjonragnar/searcher.nvim) ![](https://img.shields.io/github/stars/gudjonragnar/searcher.nvim) ![](https://img.shields.io/github/last-commit/gudjonragnar/searcher.nvim) ![](https://img.shields.io/github/commit-activity/y/gudjonragnar/searcher.nvim)
- [ulf-westermann/websearch.nvim](https://github.com/ulf-westermann/websearch.nvim) ![](https://img.shields.io/github/stars/ulf-westermann/websearch.nvim) ![](https://img.shields.io/github/last-commit/ulf-westermann/websearch.nvim) ![](https://img.shields.io/github/commit-activity/y/ulf-westermann/websearch.nvim)

#### Bookmarks

- [danarth/telescope-buku.nvim](https://github.com/danarth/telescope-buku.nvim) ![](https://img.shields.io/github/stars/danarth/telescope-buku.nvim) ![](https://img.shields.io/github/last-commit/danarth/telescope-buku.nvim) ![](https://img.shields.io/github/commit-activity/y/danarth/telescope-buku.nvim)

### Other Editor

#### VS Code

- [elijahmanor/export-to-vscode.nvim](https://github.com/elijahmanor/export-to-vscode.nvim) ![](https://img.shields.io/github/stars/elijahmanor/export-to-vscode.nvim) ![](https://img.shields.io/github/last-commit/elijahmanor/export-to-vscode.nvim) ![](https://img.shields.io/github/commit-activity/y/elijahmanor/export-to-vscode.nvim)
- [xlboy/vscode-opener.nvim](https://github.com/xlboy/vscode-opener.nvim) ![](https://img.shields.io/github/stars/xlboy/vscode-opener.nvim) ![](https://img.shields.io/github/last-commit/xlboy/vscode-opener.nvim) ![](https://img.shields.io/github/commit-activity/y/xlboy/vscode-opener.nvim)

#### Helix

- [Nossigen/helix.nvim](https://github.com/Nossigen/helix.nvim) ![](https://img.shields.io/github/stars/Nossigen/helix.nvim) ![](https://img.shields.io/github/last-commit/Nossigen/helix.nvim) ![](https://img.shields.io/github/commit-activity/y/Nossigen/helix.nvim)

#### Xcode

- [mickael-menu/ShadowVim](https://github.com/mickael-menu/ShadowVim) ![](https://img.shields.io/github/stars/mickael-menu/ShadowVim) ![](https://img.shields.io/github/last-commit/mickael-menu/ShadowVim) ![](https://img.shields.io/github/commit-activity/y/mickael-menu/ShadowVim)
- [kkharji/xbase](https://github.com/kkharji/xbase) ![](https://img.shields.io/github/stars/kkharji/xbase) ![](https://img.shields.io/github/last-commit/kkharji/xbase) ![](https://img.shields.io/github/commit-activity/y/kkharji/xbase)
- [wojciech-kulik/xcodebuild.nvim](https://github.com/wojciech-kulik/xcodebuild.nvim) ![](https://img.shields.io/github/stars/wojciech-kulik/xcodebuild.nvim) ![](https://img.shields.io/github/last-commit/wojciech-kulik/xcodebuild.nvim) ![](https://img.shields.io/github/commit-activity/y/wojciech-kulik/xcodebuild.nvim)

### JetBrains

- [vianney-g/jetbrains-scopes.nvim](https://github.com/vianney-g/jetbrains-scopes.nvim) ![](https://img.shields.io/github/stars/vianney-g/jetbrains-scopes.nvim) ![](https://img.shields.io/github/last-commit/vianney-g/jetbrains-scopes.nvim) ![](https://img.shields.io/github/commit-activity/y/vianney-g/jetbrains-scopes.nvim)

### Desktop Integration

- [simrat39/desktop-notify.nvim](https://github.com/simrat39/desktop-notify.nvim) ![](https://img.shields.io/github/stars/simrat39/desktop-notify.nvim) ![](https://img.shields.io/github/last-commit/simrat39/desktop-notify.nvim) ![](https://img.shields.io/github/commit-activity/y/simrat39/desktop-notify.nvim)
- [f-person/auto-dark-mode.nvim](https://github.com/f-person/auto-dark-mode.nvim) ![](https://img.shields.io/github/stars/f-person/auto-dark-mode.nvim) ![](https://img.shields.io/github/last-commit/f-person/auto-dark-mode.nvim) ![](https://img.shields.io/github/commit-activity/y/f-person/auto-dark-mode.nvim)
- [ObserverOfTime/notifications.nvim](https://github.com/ObserverOfTime/notifications.nvim) ![](https://img.shields.io/github/stars/ObserverOfTime/notifications.nvim) ![](https://img.shields.io/github/last-commit/ObserverOfTime/notifications.nvim) ![](https://img.shields.io/github/commit-activity/y/ObserverOfTime/notifications.nvim)

## Development environment

### Shell

- [LintaoAmons/easy-commands.nvim](https://github.com/LintaoAmons/easy-commands.nvim) ![](https://img.shields.io/github/stars/LintaoAmons/easy-commands.nvim) ![](https://img.shields.io/github/last-commit/LintaoAmons/easy-commands.nvim) ![](https://img.shields.io/github/commit-activity/y/LintaoAmons/easy-commands.nvim)

#### zsh

- [tamago324/cmp-zsh](https://github.com/tamago324/cmp-zsh) ![](https://img.shields.io/github/stars/tamago324/cmp-zsh) ![](https://img.shields.io/github/last-commit/tamago324/cmp-zsh) ![](https://img.shields.io/github/commit-activity/y/tamago324/cmp-zsh)

#### fish

- [Trard/fish_abbr.nvim](https://github.com/Trard/fish_abbr.nvim) ![](https://img.shields.io/github/stars/Trard/fish_abbr.nvim) ![](https://img.shields.io/github/last-commit/Trard/fish_abbr.nvim) ![](https://img.shields.io/github/commit-activity/y/Trard/fish_abbr.nvim)

#### nushell

- [zioroboco/nu-ls.nvim](https://github.com/zioroboco/nu-ls.nvim) ![](https://img.shields.io/github/stars/zioroboco/nu-ls.nvim) ![](https://img.shields.io/github/last-commit/zioroboco/nu-ls.nvim) ![](https://img.shields.io/github/commit-activity/y/zioroboco/nu-ls.nvim)

### GUI

#### Avalonia

- [Johanw123/avalonia.nvim](https://github.com/Johanw123/avalonia.nvim) ![](https://img.shields.io/github/stars/Johanw123/avalonia.nvim) ![](https://img.shields.io/github/last-commit/Johanw123/avalonia.nvim) ![](https://img.shields.io/github/commit-activity/y/Johanw123/avalonia.nvim)

#### Stata

- [leerauljin/do-stata.nvim](https://github.com/leerauljin/do-stata.nvim) ![](https://img.shields.io/github/stars/leerauljin/do-stata.nvim) ![](https://img.shields.io/github/last-commit/leerauljin/do-stata.nvim) ![](https://img.shields.io/github/commit-activity/y/leerauljin/do-stata.nvim)

### Terminal

#### Kitty

- [jghauser/kitty-runner.nvim](https://github.com/jghauser/kitty-runner.nvim) ![](https://img.shields.io/github/stars/jghauser/kitty-runner.nvim) ![](https://img.shields.io/github/last-commit/jghauser/kitty-runner.nvim) ![](https://img.shields.io/github/commit-activity/y/jghauser/kitty-runner.nvim)
- [romgrk/kui.nvim](https://github.com/romgrk/kui.nvim) ![](https://img.shields.io/github/stars/romgrk/kui.nvim) ![](https://img.shields.io/github/last-commit/romgrk/kui.nvim) ![](https://img.shields.io/github/commit-activity/y/romgrk/kui.nvim)
- [garyhurtz/cmp_kitty](https://github.com/garyhurtz/cmp_kitty) ![](https://img.shields.io/github/stars/garyhurtz/cmp_kitty) ![](https://img.shields.io/github/last-commit/garyhurtz/cmp_kitty) ![](https://img.shields.io/github/commit-activity/y/garyhurtz/cmp_kitty)
- [ouroboros8/nvim-kitty-navigator](https://github.com/ouroboros8/nvim-kitty-navigator) ![](https://img.shields.io/github/stars/ouroboros8/nvim-kitty-navigator) ![](https://img.shields.io/github/last-commit/ouroboros8/nvim-kitty-navigator) ![](https://img.shields.io/github/commit-activity/y/ouroboros8/nvim-kitty-navigator)
- [mikesmithgh/kitty-scrollback.nvim](https://github.com/mikesmithgh/kitty-scrollback.nvim) ![](https://img.shields.io/github/stars/mikesmithgh/kitty-scrollback.nvim) ![](https://img.shields.io/github/last-commit/mikesmithgh/kitty-scrollback.nvim) ![](https://img.shields.io/github/commit-activity/y/mikesmithgh/kitty-scrollback.nvim)
- [MunsMan/kitty-navigator.nvim](https://github.com/MunsMan/kitty-navigator.nvim) ![](https://img.shields.io/github/stars/MunsMan/kitty-navigator.nvim) ![](https://img.shields.io/github/last-commit/MunsMan/kitty-navigator.nvim) ![](https://img.shields.io/github/commit-activity/y/MunsMan/kitty-navigator.nvim)
- [RAprogramm/nekifoch](https://github.com/RAprogramm/nekifoch) ![](https://img.shields.io/github/stars/RAprogramm/nekifoch) ![](https://img.shields.io/github/last-commit/RAprogramm/nekifoch) ![](https://img.shields.io/github/commit-activity/y/RAprogramm/nekifoch)

##### Image

- [eduardotlc/telescope-du-preview.nvim](https://github.com/eduardotlc/telescope-du-preview.nvim) ![](https://img.shields.io/github/stars/eduardotlc/telescope-du-preview.nvim) ![](https://img.shields.io/github/last-commit/eduardotlc/telescope-du-preview.nvim) ![](https://img.shields.io/github/commit-activity/y/eduardotlc/telescope-du-preview.nvim)

#### WezTerm

- [willothy/wezterm.nvim](https://github.com/willothy/wezterm.nvim) ![](https://img.shields.io/github/stars/willothy/wezterm.nvim) ![](https://img.shields.io/github/last-commit/willothy/wezterm.nvim) ![](https://img.shields.io/github/commit-activity/y/willothy/wezterm.nvim)
- [winter-again/wezterm-config.nvim](https://github.com/winter-again/wezterm-config.nvim) ![](https://img.shields.io/github/stars/winter-again/wezterm-config.nvim) ![](https://img.shields.io/github/last-commit/winter-again/wezterm-config.nvim) ![](https://img.shields.io/github/commit-activity/y/winter-again/wezterm-config.nvim)
- [paytonward6/nvim-wezlime](https://github.com/paytonward6/nvim-wezlime) ![](https://img.shields.io/github/stars/paytonward6/nvim-wezlime) ![](https://img.shields.io/github/last-commit/paytonward6/nvim-wezlime) ![](https://img.shields.io/github/commit-activity/y/paytonward6/nvim-wezlime)

#### Windows Terminal

- [BlueKossa/windows-terminal-bg.nvim](https://github.com/BlueKossa/windows-terminal-bg.nvim) ![](https://img.shields.io/github/stars/BlueKossa/windows-terminal-bg.nvim) ![](https://img.shields.io/github/last-commit/BlueKossa/windows-terminal-bg.nvim) ![](https://img.shields.io/github/commit-activity/y/BlueKossa/windows-terminal-bg.nvim)

### Infra

#### OpenStack

- [yasufum/os-tox.nvim](https://github.com/yasufum/os-tox.nvim) ![](https://img.shields.io/github/stars/yasufum/os-tox.nvim) ![](https://img.shields.io/github/last-commit/yasufum/os-tox.nvim) ![](https://img.shields.io/github/commit-activity/y/yasufum/os-tox.nvim)

#### SonarLint

- [alnav3/sonarlint.nvim](https://github.com/alnav3/sonarlint.nvim) ![](https://img.shields.io/github/stars/alnav3/sonarlint.nvim) ![](https://img.shields.io/github/last-commit/alnav3/sonarlint.nvim) ![](https://img.shields.io/github/commit-activity/y/alnav3/sonarlint.nvim)

#### Kafka

- [krisajenkins/telescope-kafka.nvim](https://github.com/krisajenkins/telescope-kafka.nvim) ![](https://img.shields.io/github/stars/krisajenkins/telescope-kafka.nvim) ![](https://img.shields.io/github/last-commit/krisajenkins/telescope-kafka.nvim) ![](https://img.shields.io/github/commit-activity/y/krisajenkins/telescope-kafka.nvim)

#### Dataform

- [magal1337/dataform.nvim](https://github.com/magal1337/dataform.nvim) ![](https://img.shields.io/github/stars/magal1337/dataform.nvim) ![](https://img.shields.io/github/last-commit/magal1337/dataform.nvim) ![](https://img.shields.io/github/commit-activity/y/magal1337/dataform.nvim)

### Cloud

#### Terraform

- [azratul/devops-tools.nvim](https://github.com/azratul/devops-tools.nvim) ![](https://img.shields.io/github/stars/azratul/devops-tools.nvim) ![](https://img.shields.io/github/last-commit/azratul/devops-tools.nvim) ![](https://img.shields.io/github/commit-activity/y/azratul/devops-tools.nvim)
- [mvaldes14/terraform.nvim](https://github.com/mvaldes14/terraform.nvim) ![](https://img.shields.io/github/stars/mvaldes14/terraform.nvim) ![](https://img.shields.io/github/last-commit/mvaldes14/terraform.nvim) ![](https://img.shields.io/github/commit-activity/y/mvaldes14/terraform.nvim)
- [raphapr/terraform.nvim](https://github.com/raphapr/terraform.nvim) ![](https://img.shields.io/github/stars/raphapr/terraform.nvim) ![](https://img.shields.io/github/last-commit/raphapr/terraform.nvim) ![](https://img.shields.io/github/commit-activity/y/raphapr/terraform.nvim)
- [dakota-m/terraform.nvim](https://github.com/dakota-m/terraform.nvim) ![](https://img.shields.io/github/stars/dakota-m/terraform.nvim) ![](https://img.shields.io/github/last-commit/dakota-m/terraform.nvim) ![](https://img.shields.io/github/commit-activity/y/dakota-m/terraform.nvim)
- [olidacombe/terrabastard.nvim](https://github.com/olidacombe/terrabastard.nvim) ![](https://img.shields.io/github/stars/olidacombe/terrabastard.nvim) ![](https://img.shields.io/github/last-commit/olidacombe/terrabastard.nvim) ![](https://img.shields.io/github/commit-activity/y/olidacombe/terrabastard.nvim)

#### Ansible

- [mfussenegger/nvim-ansible](https://github.com/mfussenegger/nvim-ansible) ![](https://img.shields.io/github/stars/mfussenegger/nvim-ansible) ![](https://img.shields.io/github/last-commit/mfussenegger/nvim-ansible) ![](https://img.shields.io/github/commit-activity/y/mfussenegger/nvim-ansible)

#### Kustomize

- [Allaman/kustomize.nvim](https://github.com/Allaman/kustomize.nvim) ![](https://img.shields.io/github/stars/Allaman/kustomize.nvim) ![](https://img.shields.io/github/last-commit/Allaman/kustomize.nvim) ![](https://img.shields.io/github/commit-activity/y/Allaman/kustomize.nvim)

#### AWS

- [lunarxlark/telescope-aws.nvim](https://github.com/lunarxlark/telescope-aws.nvim) ![](https://img.shields.io/github/stars/lunarxlark/telescope-aws.nvim) ![](https://img.shields.io/github/last-commit/lunarxlark/telescope-aws.nvim) ![](https://img.shields.io/github/commit-activity/y/lunarxlark/telescope-aws.nvim)
- [harryvince/aws-sdk.nvim](https://github.com/harryvince/aws-sdk.nvim) ![](https://img.shields.io/github/stars/harryvince/aws-sdk.nvim) ![](https://img.shields.io/github/last-commit/harryvince/aws-sdk.nvim) ![](https://img.shields.io/github/commit-activity/y/harryvince/aws-sdk.nvim)

##### S3

- [kiran94/s3edit.nvim](https://github.com/kiran94/s3edit.nvim) ![](https://img.shields.io/github/stars/kiran94/s3edit.nvim) ![](https://img.shields.io/github/last-commit/kiran94/s3edit.nvim) ![](https://img.shields.io/github/commit-activity/y/kiran94/s3edit.nvim)

##### CloudWatch

- [DiscretePython/cw.nvim](https://github.com/DiscretePython/cw.nvim) ![](https://img.shields.io/github/stars/DiscretePython/cw.nvim) ![](https://img.shields.io/github/last-commit/DiscretePython/cw.nvim) ![](https://img.shields.io/github/commit-activity/y/DiscretePython/cw.nvim)
- [michaelPotter/cloudwatchInsights.nvim](https://github.com/michaelPotter/cloudwatchInsights.nvim) ![](https://img.shields.io/github/stars/michaelPotter/cloudwatchInsights.nvim) ![](https://img.shields.io/github/last-commit/michaelPotter/cloudwatchInsights.nvim) ![](https://img.shields.io/github/commit-activity/y/michaelPotter/cloudwatchInsights.nvim)

#### Azure

- [interludedesign/azureutils.nvim](https://github.com/interludedesign/azureutils.nvim) ![](https://img.shields.io/github/stars/interludedesign/azureutils.nvim) ![](https://img.shields.io/github/last-commit/interludedesign/azureutils.nvim) ![](https://img.shields.io/github/commit-activity/y/interludedesign/azureutils.nvim)
- [maxrzaw/azdo.nvim](https://github.com/maxrzaw/azdo.nvim) ![](https://img.shields.io/github/stars/maxrzaw/azdo.nvim) ![](https://img.shields.io/github/last-commit/maxrzaw/azdo.nvim) ![](https://img.shields.io/github/commit-activity/y/maxrzaw/azdo.nvim)
- [KaiWalter/azure-functions.nvim](https://github.com/KaiWalter/azure-functions.nvim) ![](https://img.shields.io/github/stars/KaiWalter/azure-functions.nvim) ![](https://img.shields.io/github/last-commit/KaiWalter/azure-functions.nvim) ![](https://img.shields.io/github/commit-activity/y/KaiWalter/azure-functions.nvim)
- [danarth/telescope-ado.nvim](https://github.com/danarth/telescope-ado.nvim) ![](https://img.shields.io/github/stars/danarth/telescope-ado.nvim) ![](https://img.shields.io/github/last-commit/danarth/telescope-ado.nvim) ![](https://img.shields.io/github/commit-activity/y/danarth/telescope-ado.nvim)
- [dan-nicholls/azure-cli.nvim](https://github.com/dan-nicholls/azure-cli.nvim) ![](https://img.shields.io/github/stars/dan-nicholls/azure-cli.nvim) ![](https://img.shields.io/github/last-commit/dan-nicholls/azure-cli.nvim) ![](https://img.shields.io/github/commit-activity/y/dan-nicholls/azure-cli.nvim)

#### Salesforce

- [NazgoooAtanasov/sfcc-debugger.nvim](https://github.com/NazgoooAtanasov/sfcc-debugger.nvim) ![](https://img.shields.io/github/stars/NazgoooAtanasov/sfcc-debugger.nvim) ![](https://img.shields.io/github/last-commit/NazgoooAtanasov/sfcc-debugger.nvim) ![](https://img.shields.io/github/commit-activity/y/NazgoooAtanasov/sfcc-debugger.nvim)
- [g-duff/sf.nvim](https://github.com/g-duff/sf.nvim) ![](https://img.shields.io/github/stars/g-duff/sf.nvim) ![](https://img.shields.io/github/last-commit/g-duff/sf.nvim) ![](https://img.shields.io/github/commit-activity/y/g-duff/sf.nvim)
- [devinjc213/sfdeez.nvim](https://github.com/devinjc213/sfdeez.nvim) ![](https://img.shields.io/github/stars/devinjc213/sfdeez.nvim) ![](https://img.shields.io/github/last-commit/devinjc213/sfdeez.nvim) ![](https://img.shields.io/github/commit-activity/y/devinjc213/sfdeez.nvim)
- [jonathanmorris180/salesforce.nvim](https://github.com/jonathanmorris180/salesforce.nvim) ![](https://img.shields.io/github/stars/jonathanmorris180/salesforce.nvim) ![](https://img.shields.io/github/last-commit/jonathanmorris180/salesforce.nvim) ![](https://img.shields.io/github/commit-activity/y/jonathanmorris180/salesforce.nvim)
- [KanesAccount/lazysf.nvim](https://github.com/KanesAccount/lazysf.nvim) ![](https://img.shields.io/github/stars/KanesAccount/lazysf.nvim) ![](https://img.shields.io/github/last-commit/KanesAccount/lazysf.nvim) ![](https://img.shields.io/github/commit-activity/y/KanesAccount/lazysf.nvim)

#### dbt

- [cfmeyers/dbt.nvim](https://github.com/cfmeyers/dbt.nvim) ![](https://img.shields.io/github/stars/cfmeyers/dbt.nvim) ![](https://img.shields.io/github/last-commit/cfmeyers/dbt.nvim) ![](https://img.shields.io/github/commit-activity/y/cfmeyers/dbt.nvim)

#### sdfcli

### Ethereum

#### foundry

### Password Manager

- [nacro90/omen.nvim](https://github.com/nacro90/omen.nvim) ![](https://img.shields.io/github/stars/nacro90/omen.nvim) ![](https://img.shields.io/github/last-commit/nacro90/omen.nvim) ![](https://img.shields.io/github/commit-activity/y/nacro90/omen.nvim)
- [mrjones2014/op.nvim](https://github.com/mrjones2014/op.nvim) ![](https://img.shields.io/github/stars/mrjones2014/op.nvim) ![](https://img.shields.io/github/last-commit/mrjones2014/op.nvim) ![](https://img.shields.io/github/commit-activity/y/mrjones2014/op.nvim)
- [NeverW8/nvim_pw.nvim](https://github.com/NeverW8/nvim_pw.nvim) ![](https://img.shields.io/github/stars/NeverW8/nvim_pw.nvim) ![](https://img.shields.io/github/last-commit/NeverW8/nvim_pw.nvim) ![](https://img.shields.io/github/commit-activity/y/NeverW8/nvim_pw.nvim)
- [jwvictor/nvim-cubby](https://github.com/jwvictor/nvim-cubby) ![](https://img.shields.io/github/stars/jwvictor/nvim-cubby) ![](https://img.shields.io/github/last-commit/jwvictor/nvim-cubby) ![](https://img.shields.io/github/commit-activity/y/jwvictor/nvim-cubby)

### IME

- [nitomoki/JPmode.nvim](https://github.com/nitomoki/JPmode.nvim) ![](https://img.shields.io/github/stars/nitomoki/JPmode.nvim) ![](https://img.shields.io/github/last-commit/nitomoki/JPmode.nvim) ![](https://img.shields.io/github/commit-activity/y/nitomoki/JPmode.nvim)
- [keaising/im-select.nvim](https://github.com/keaising/im-select.nvim) ![](https://img.shields.io/github/stars/keaising/im-select.nvim) ![](https://img.shields.io/github/last-commit/keaising/im-select.nvim) ![](https://img.shields.io/github/commit-activity/y/keaising/im-select.nvim)
- [uga-rosa/jam.nvim](https://github.com/uga-rosa/jam.nvim) ![](https://img.shields.io/github/stars/uga-rosa/jam.nvim) ![](https://img.shields.io/github/last-commit/uga-rosa/jam.nvim) ![](https://img.shields.io/github/commit-activity/y/uga-rosa/jam.nvim)
- [haolian9/normalascii.nvim](https://github.com/haolian9/normalascii.nvim) ![](https://img.shields.io/github/stars/haolian9/normalascii.nvim) ![](https://img.shields.io/github/last-commit/haolian9/normalascii.nvim) ![](https://img.shields.io/github/commit-activity/y/haolian9/normalascii.nvim)
- [hosxy/IMSwitch.nvim](https://github.com/hosxy/IMSwitch.nvim) ![](https://img.shields.io/github/stars/hosxy/IMSwitch.nvim) ![](https://img.shields.io/github/last-commit/hosxy/IMSwitch.nvim) ![](https://img.shields.io/github/commit-activity/y/hosxy/IMSwitch.nvim)
- [wingforth/nvim-im-select](https://github.com/wingforth/nvim-im-select) ![](https://img.shields.io/github/stars/wingforth/nvim-im-select) ![](https://img.shields.io/github/last-commit/wingforth/nvim-im-select) ![](https://img.shields.io/github/commit-activity/y/wingforth/nvim-im-select)
- [fengwk/im-switch.nvim](https://github.com/fengwk/im-switch.nvim) ![](https://img.shields.io/github/stars/fengwk/im-switch.nvim) ![](https://img.shields.io/github/last-commit/fengwk/im-switch.nvim) ![](https://img.shields.io/github/commit-activity/y/fengwk/im-switch.nvim)
- [Wansmer/langmapper.nvim](https://github.com/Wansmer/langmapper.nvim) ![](https://img.shields.io/github/stars/Wansmer/langmapper.nvim) ![](https://img.shields.io/github/last-commit/Wansmer/langmapper.nvim) ![](https://img.shields.io/github/commit-activity/y/Wansmer/langmapper.nvim)
- [delphinus/skkeleton_indicator.nvim](https://github.com/delphinus/skkeleton_indicator.nvim) ![](https://img.shields.io/github/stars/delphinus/skkeleton_indicator.nvim) ![](https://img.shields.io/github/last-commit/delphinus/skkeleton_indicator.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/skkeleton_indicator.nvim)
- [5long/imdi.nvim](https://github.com/5long/imdi.nvim) ![](https://img.shields.io/github/stars/5long/imdi.nvim) ![](https://img.shields.io/github/last-commit/5long/imdi.nvim) ![](https://img.shields.io/github/commit-activity/y/5long/imdi.nvim)
- [TD-Sky/fcitx.nvim](https://github.com/TD-Sky/fcitx.nvim) ![](https://img.shields.io/github/stars/TD-Sky/fcitx.nvim) ![](https://img.shields.io/github/last-commit/TD-Sky/fcitx.nvim) ![](https://img.shields.io/github/commit-activity/y/TD-Sky/fcitx.nvim)
- [crispgm/nvim-auto-ime](https://github.com/crispgm/nvim-auto-ime) ![](https://img.shields.io/github/stars/crispgm/nvim-auto-ime) ![](https://img.shields.io/github/last-commit/crispgm/nvim-auto-ime) ![](https://img.shields.io/github/commit-activity/y/crispgm/nvim-auto-ime)
- [Xx1gS/clef.nvim](https://github.com/Xx1gS/clef.nvim) ![](https://img.shields.io/github/stars/Xx1gS/clef.nvim) ![](https://img.shields.io/github/last-commit/Xx1gS/clef.nvim) ![](https://img.shields.io/github/commit-activity/y/Xx1gS/clef.nvim)
- [wangl-cc/im-switch.nvim](https://github.com/wangl-cc/im-switch.nvim) ![](https://img.shields.io/github/stars/wangl-cc/im-switch.nvim) ![](https://img.shields.io/github/last-commit/wangl-cc/im-switch.nvim) ![](https://img.shields.io/github/commit-activity/y/wangl-cc/im-switch.nvim)
- [yangrq1018/im-switch.nvim](https://github.com/yangrq1018/im-switch.nvim) ![](https://img.shields.io/github/stars/yangrq1018/im-switch.nvim) ![](https://img.shields.io/github/last-commit/yangrq1018/im-switch.nvim) ![](https://img.shields.io/github/commit-activity/y/yangrq1018/im-switch.nvim)
- [drop-stones/im-switch.nvim](https://github.com/drop-stones/im-switch.nvim) ![](https://img.shields.io/github/stars/drop-stones/im-switch.nvim) ![](https://img.shields.io/github/last-commit/drop-stones/im-switch.nvim) ![](https://img.shields.io/github/commit-activity/y/drop-stones/im-switch.nvim)
- [MagicMarvel/smart-im-select.nvim](https://github.com/MagicMarvel/smart-im-select.nvim) ![](https://img.shields.io/github/stars/MagicMarvel/smart-im-select.nvim) ![](https://img.shields.io/github/last-commit/MagicMarvel/smart-im-select.nvim) ![](https://img.shields.io/github/commit-activity/y/MagicMarvel/smart-im-select.nvim)
- [puddings233/fcitx5-switcher.nvim](https://github.com/puddings233/fcitx5-switcher.nvim) ![](https://img.shields.io/github/stars/puddings233/fcitx5-switcher.nvim) ![](https://img.shields.io/github/last-commit/puddings233/fcitx5-switcher.nvim) ![](https://img.shields.io/github/commit-activity/y/puddings233/fcitx5-switcher.nvim)

#### Fcitx

- [tonyfettes/fcitx5.nvim](https://github.com/tonyfettes/fcitx5.nvim) ![](https://img.shields.io/github/stars/tonyfettes/fcitx5.nvim) ![](https://img.shields.io/github/last-commit/tonyfettes/fcitx5.nvim) ![](https://img.shields.io/github/commit-activity/y/tonyfettes/fcitx5.nvim)
- [alohaia/fcitx.nvim](https://github.com/alohaia/fcitx.nvim) ![](https://img.shields.io/github/stars/alohaia/fcitx.nvim) ![](https://img.shields.io/github/last-commit/alohaia/fcitx.nvim) ![](https://img.shields.io/github/commit-activity/y/alohaia/fcitx.nvim)
- [smartding/fcitx.nvim](https://github.com/smartding/fcitx.nvim) ![](https://img.shields.io/github/stars/smartding/fcitx.nvim) ![](https://img.shields.io/github/last-commit/smartding/fcitx.nvim) ![](https://img.shields.io/github/commit-activity/y/smartding/fcitx.nvim)
- [pysan3/fcitx5.nvim](https://github.com/pysan3/fcitx5.nvim) ![](https://img.shields.io/github/stars/pysan3/fcitx5.nvim) ![](https://img.shields.io/github/last-commit/pysan3/fcitx5.nvim) ![](https://img.shields.io/github/commit-activity/y/pysan3/fcitx5.nvim)
- [hnjae/fcitx.nvim](https://github.com/hnjae/fcitx.nvim) ![](https://img.shields.io/github/stars/hnjae/fcitx.nvim) ![](https://img.shields.io/github/last-commit/hnjae/fcitx.nvim) ![](https://img.shields.io/github/commit-activity/y/hnjae/fcitx.nvim)
- [niuiic/fcitx.nvim](https://github.com/niuiic/fcitx.nvim) ![](https://img.shields.io/github/stars/niuiic/fcitx.nvim) ![](https://img.shields.io/github/last-commit/niuiic/fcitx.nvim) ![](https://img.shields.io/github/commit-activity/y/niuiic/fcitx.nvim)
- [OliverChao/autoime.nvim](https://github.com/OliverChao/autoime.nvim) ![](https://img.shields.io/github/stars/OliverChao/autoime.nvim) ![](https://img.shields.io/github/last-commit/OliverChao/autoime.nvim) ![](https://img.shields.io/github/commit-activity/y/OliverChao/autoime.nvim)
- [SR-MyStar/fcitx5-switch.nvim](https://github.com/SR-MyStar/fcitx5-switch.nvim) ![](https://img.shields.io/github/stars/SR-MyStar/fcitx5-switch.nvim) ![](https://img.shields.io/github/last-commit/SR-MyStar/fcitx5-switch.nvim) ![](https://img.shields.io/github/commit-activity/y/SR-MyStar/fcitx5-switch.nvim)

#### SKK

- [rinx/cmp-skkeleton](https://github.com/rinx/cmp-skkeleton) ![](https://img.shields.io/github/stars/rinx/cmp-skkeleton) ![](https://img.shields.io/github/last-commit/rinx/cmp-skkeleton) ![](https://img.shields.io/github/commit-activity/y/rinx/cmp-skkeleton)
- [delphinus/skkeleton_indicator.nvim](https://github.com/delphinus/skkeleton_indicator.nvim) ![](https://img.shields.io/github/stars/delphinus/skkeleton_indicator.nvim) ![](https://img.shields.io/github/last-commit/delphinus/skkeleton_indicator.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/skkeleton_indicator.nvim)
- [uga-rosa/cmp-skkeleton](https://github.com/uga-rosa/cmp-skkeleton) ![](https://img.shields.io/github/stars/uga-rosa/cmp-skkeleton) ![](https://img.shields.io/github/last-commit/uga-rosa/cmp-skkeleton) ![](https://img.shields.io/github/commit-activity/y/uga-rosa/cmp-skkeleton)
- [yuys13/skk-develop.nvim](https://github.com/yuys13/skk-develop.nvim) ![](https://img.shields.io/github/stars/yuys13/skk-develop.nvim) ![](https://img.shields.io/github/last-commit/yuys13/skk-develop.nvim) ![](https://img.shields.io/github/commit-activity/y/yuys13/skk-develop.nvim)

#### migemo

- [sei40kr/migemo-search.nvim](https://github.com/sei40kr/migemo-search.nvim) ![](https://img.shields.io/github/stars/sei40kr/migemo-search.nvim) ![](https://img.shields.io/github/last-commit/sei40kr/migemo-search.nvim) ![](https://img.shields.io/github/commit-activity/y/sei40kr/migemo-search.nvim)

### Battery

- [justinhj/battery.nvim](https://github.com/justinhj/battery.nvim) ![](https://img.shields.io/github/stars/justinhj/battery.nvim) ![](https://img.shields.io/github/last-commit/justinhj/battery.nvim) ![](https://img.shields.io/github/commit-activity/y/justinhj/battery.nvim)

### Audio

#### SuperCollider

- [madskjeldgaard/telescope-supercollider.nvim](https://github.com/madskjeldgaard/telescope-supercollider.nvim) ![](https://img.shields.io/github/stars/madskjeldgaard/telescope-supercollider.nvim) ![](https://img.shields.io/github/last-commit/madskjeldgaard/telescope-supercollider.nvim) ![](https://img.shields.io/github/commit-activity/y/madskjeldgaard/telescope-supercollider.nvim)

#### LilyPond

- [martineausimon/nvim-lilypond-suite](https://github.com/martineausimon/nvim-lilypond-suite) ![](https://img.shields.io/github/stars/martineausimon/nvim-lilypond-suite) ![](https://img.shields.io/github/last-commit/martineausimon/nvim-lilypond-suite) ![](https://img.shields.io/github/commit-activity/y/martineausimon/nvim-lilypond-suite)
