# Table of Contents

<!-- toc -->

- [Table](#table)
- [Class](#class)
- [Log](#log)
- [async](#async)
- [Coroutine](#coroutine)
- [Reactive](#reactive)
- [String](#string)
- [File](#file)
  * [Path](#path)
- [Exec](#exec)
- [Config](#config)
- [Control another neovim](#control-another-neovim)
- [UI](#ui)
  * [Notification](#notification)
  * [vim.ui.select/vim.ui.input](#vimuiselectvimuiinput)
  * [Popup](#popup)
  * [Animation](#animation)
  * [FuzzyFinder](#fuzzyfinder)
  * [Spinner](#spinner)
- [Error handling](#error-handling)
- [Assert](#assert)
- [Time](#time)
- [UUID](#uuid)
- [Net](#net)
  * [HTTP](#http)
  * [Curl](#curl)
  * [Hurl](#hurl)
  * [REST](#rest)
  * [GRPC](#grpc)
  * [WebSocket](#websocket)
- [JSON](#json)
- [Require](#require)
- [Hook](#hook)
- [Mode](#mode)
- [Buffer](#buffer)
- [Keymap](#keymap)
- [autocmd](#autocmd)
- [Color](#color)
- [Icon](#icon)
- [Date](#date)
- [Unicode](#unicode)
- [random variable names](#random-variable-names)
- [Mathematics](#mathematics)
- [Treesitter](#treesitter)
- [Enhanced Standard Features](#enhanced-standard-features)
- [Util wrapper](#util-wrapper)

<!-- tocstop -->

## Table

- [darksinge/neodash.nvim](https://github.com/darksinge/neodash.nvim) ![](https://img.shields.io/github/stars/darksinge/neodash.nvim) ![](https://img.shields.io/github/last-commit/darksinge/neodash.nvim) ![](https://img.shields.io/github/commit-activity/y/darksinge/neodash.nvim)

## Class

- [anuvyklack/middleclass](https://github.com/anuvyklack/middleclass) ![](https://img.shields.io/github/stars/anuvyklack/middleclass) ![](https://img.shields.io/github/last-commit/anuvyklack/middleclass) ![](https://img.shields.io/github/commit-activity/y/anuvyklack/middleclass)

## Log

- [tjdevries/vlog.nvim](https://github.com/tjdevries/vlog.nvim) ![](https://img.shields.io/github/stars/tjdevries/vlog.nvim) ![](https://img.shields.io/github/last-commit/tjdevries/vlog.nvim) ![](https://img.shields.io/github/commit-activity/y/tjdevries/vlog.nvim)
- [Tastyep/structlog.nvim](https://github.com/Tastyep/structlog.nvim) ![](https://img.shields.io/github/stars/Tastyep/structlog.nvim) ![](https://img.shields.io/github/last-commit/Tastyep/structlog.nvim) ![](https://img.shields.io/github/commit-activity/y/Tastyep/structlog.nvim)
- [rmagatti/logger.nvim](https://github.com/rmagatti/logger.nvim) ![](https://img.shields.io/github/stars/rmagatti/logger.nvim) ![](https://img.shields.io/github/last-commit/rmagatti/logger.nvim) ![](https://img.shields.io/github/commit-activity/y/rmagatti/logger.nvim)
- [novicedev7291/consolelog.nvim](https://github.com/novicedev7291/consolelog.nvim) ![](https://img.shields.io/github/stars/novicedev7291/consolelog.nvim) ![](https://img.shields.io/github/last-commit/novicedev7291/consolelog.nvim) ![](https://img.shields.io/github/commit-activity/y/novicedev7291/consolelog.nvim)
- [NTBBloodbath/logging.nvim](https://github.com/NTBBloodbath/logging.nvim) ![](https://img.shields.io/github/stars/NTBBloodbath/logging.nvim) ![](https://img.shields.io/github/last-commit/NTBBloodbath/logging.nvim) ![](https://img.shields.io/github/commit-activity/y/NTBBloodbath/logging.nvim)

## async

- [nvim-lua/plenary.nvim(async)](https://github.com/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/stars/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/last-commit/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-lua/plenary.nvim)
- [ms-jpq/lua-async-await](https://github.com/ms-jpq/lua-async-await) ![](https://img.shields.io/github/stars/ms-jpq/lua-async-await) ![](https://img.shields.io/github/last-commit/ms-jpq/lua-async-await) ![](https://img.shields.io/github/commit-activity/y/ms-jpq/lua-async-await)
- [notomo/promise.nvim](https://github.com/notomo/promise.nvim) ![](https://img.shields.io/github/stars/notomo/promise.nvim) ![](https://img.shields.io/github/last-commit/notomo/promise.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/promise.nvim)
- [iamcco/async-await.lua](https://github.com/iamcco/async-await.lua) ![](https://img.shields.io/github/stars/iamcco/async-await.lua) ![](https://img.shields.io/github/last-commit/iamcco/async-await.lua) ![](https://img.shields.io/github/commit-activity/y/iamcco/async-await.lua)
- [kevinhwang91/promise-async](https://github.com/kevinhwang91/promise-async) ![](https://img.shields.io/github/stars/kevinhwang91/promise-async) ![](https://img.shields.io/github/last-commit/kevinhwang91/promise-async) ![](https://img.shields.io/github/commit-activity/y/kevinhwang91/promise-async)
- [lewis6991/async.nvim](https://github.com/lewis6991/async.nvim) ![](https://img.shields.io/github/stars/lewis6991/async.nvim) ![](https://img.shields.io/github/last-commit/lewis6991/async.nvim) ![](https://img.shields.io/github/commit-activity/y/lewis6991/async.nvim)
- [ec965/async-uv.nvim](https://github.com/ec965/async-uv.nvim) ![](https://img.shields.io/github/stars/ec965/async-uv.nvim) ![](https://img.shields.io/github/last-commit/ec965/async-uv.nvim) ![](https://img.shields.io/github/commit-activity/y/ec965/async-uv.nvim)
- [willothy/micro-async.nvim](https://github.com/willothy/micro-async.nvim) ![](https://img.shields.io/github/stars/willothy/micro-async.nvim) ![](https://img.shields.io/github/last-commit/willothy/micro-async.nvim) ![](https://img.shields.io/github/commit-activity/y/willothy/micro-async.nvim)
- [svermeulen/nvim-lusc](https://github.com/svermeulen/nvim-lusc) ![](https://img.shields.io/github/stars/svermeulen/nvim-lusc) ![](https://img.shields.io/github/last-commit/svermeulen/nvim-lusc) ![](https://img.shields.io/github/commit-activity/y/svermeulen/nvim-lusc)
- [nvim-neotest/nvim-nio](https://github.com/nvim-neotest/nvim-nio) ![](https://img.shields.io/github/stars/nvim-neotest/nvim-nio) ![](https://img.shields.io/github/last-commit/nvim-neotest/nvim-nio) ![](https://img.shields.io/github/commit-activity/y/nvim-neotest/nvim-nio)

## Coroutine

- [idanarye/nvim-channelot](https://github.com/idanarye/nvim-channelot) ![](https://img.shields.io/github/stars/idanarye/nvim-channelot) ![](https://img.shields.io/github/last-commit/idanarye/nvim-channelot) ![](https://img.shields.io/github/commit-activity/y/idanarye/nvim-channelot)

## Reactive

- [pvsfair/reactivex.nvim](https://github.com/pvsfair/reactivex.nvim) ![](https://img.shields.io/github/stars/pvsfair/reactivex.nvim) ![](https://img.shields.io/github/last-commit/pvsfair/reactivex.nvim) ![](https://img.shields.io/github/commit-activity/y/pvsfair/reactivex.nvim)

## String

- [jsMRSoL/txtin.nvim](https://github.com/jsMRSoL/txtin.nvim) ![](https://img.shields.io/github/stars/jsMRSoL/txtin.nvim) ![](https://img.shields.io/github/last-commit/jsMRSoL/txtin.nvim) ![](https://img.shields.io/github/commit-activity/y/jsMRSoL/txtin.nvim)

## File

- [nvim-lua/plenary.nvim(file)](https://github.com/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/stars/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/last-commit/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-lua/plenary.nvim)

### Path

- [pysan3/pathlib.nvim](https://github.com/pysan3/pathlib.nvim) ![](https://img.shields.io/github/stars/pysan3/pathlib.nvim) ![](https://img.shields.io/github/last-commit/pysan3/pathlib.nvim) ![](https://img.shields.io/github/commit-activity/y/pysan3/pathlib.nvim)

## Exec

- [cyn1x/outhouse.nvim](https://github.com/cyn1x/outhouse.nvim) ![](https://img.shields.io/github/stars/cyn1x/outhouse.nvim) ![](https://img.shields.io/github/last-commit/cyn1x/outhouse.nvim) ![](https://img.shields.io/github/commit-activity/y/cyn1x/outhouse.nvim)

## Config

- [abcdefg233/hcutil.nvim](https://github.com/abcdefg233/hcutil.nvim) ![](https://img.shields.io/github/stars/abcdefg233/hcutil.nvim) ![](https://img.shields.io/github/last-commit/abcdefg233/hcutil.nvim) ![](https://img.shields.io/github/commit-activity/y/abcdefg233/hcutil.nvim)

## Control another neovim 

- [HiPhish/yo-dawg.nvim](https://github.com/HiPhish/yo-dawg.nvim) ![](https://img.shields.io/github/stars/HiPhish/yo-dawg.nvim) ![](https://img.shields.io/github/last-commit/HiPhish/yo-dawg.nvim) ![](https://img.shields.io/github/commit-activity/y/HiPhish/yo-dawg.nvim)

## UI

- [MunifTanjim/nui.nvim](https://github.com/MunifTanjim/nui.nvim) ![](https://img.shields.io/github/stars/MunifTanjim/nui.nvim) ![](https://img.shields.io/github/last-commit/MunifTanjim/nui.nvim) ![](https://img.shields.io/github/commit-activity/y/MunifTanjim/nui.nvim)
  - [grapp-dev/nui-components.nvim](https://github.com/grapp-dev/nui-components.nvim) ![](https://img.shields.io/github/stars/grapp-dev/nui-components.nvim) ![](https://img.shields.io/github/last-commit/grapp-dev/nui-components.nvim) ![](https://img.shields.io/github/commit-activity/y/grapp-dev/nui-components.nvim)

### Notification

- [rcarriga/nvim-notify](https://github.com/rcarriga/nvim-notify) ![](https://img.shields.io/github/stars/rcarriga/nvim-notify) ![](https://img.shields.io/github/last-commit/rcarriga/nvim-notify) ![](https://img.shields.io/github/commit-activity/y/rcarriga/nvim-notify)
- [folke/noice.nvim(notify)](https://github.com/folke/noice.nvim) ![](https://img.shields.io/github/stars/folke/noice.nvim) ![](https://img.shields.io/github/last-commit/folke/noice.nvim) ![](https://img.shields.io/github/commit-activity/y/folke/noice.nvim)
- [Ajnasz/notify-send.nvim](https://github.com/Ajnasz/notify-send.nvim) ![](https://img.shields.io/github/stars/Ajnasz/notify-send.nvim) ![](https://img.shields.io/github/last-commit/Ajnasz/notify-send.nvim) ![](https://img.shields.io/github/commit-activity/y/Ajnasz/notify-send.nvim)

### vim.ui.select/vim.ui.input

- [stevearc/dressing.nvim](https://github.com/stevearc/dressing.nvim) ![](https://img.shields.io/github/stars/stevearc/dressing.nvim) ![](https://img.shields.io/github/last-commit/stevearc/dressing.nvim) ![](https://img.shields.io/github/commit-activity/y/stevearc/dressing.nvim)
- [doums/suit.nvim](https://github.com/doums/suit.nvim) ![](https://img.shields.io/github/stars/doums/suit.nvim) ![](https://img.shields.io/github/last-commit/doums/suit.nvim) ![](https://img.shields.io/github/commit-activity/y/doums/suit.nvim)
- [hood/popui.nvim](https://github.com/hood/popui.nvim) ![](https://img.shields.io/github/stars/hood/popui.nvim) ![](https://img.shields.io/github/last-commit/hood/popui.nvim) ![](https://img.shields.io/github/commit-activity/y/hood/popui.nvim)
- [mfussenegger/nvim-qwahl](https://github.com/mfussenegger/nvim-qwahl) ![](https://img.shields.io/github/stars/mfussenegger/nvim-qwahl) ![](https://img.shields.io/github/last-commit/mfussenegger/nvim-qwahl) ![](https://img.shields.io/github/commit-activity/y/mfussenegger/nvim-qwahl)
- [liangxianzhe/floating-input.nvim](https://github.com/liangxianzhe/floating-input.nvim) ![](https://img.shields.io/github/stars/liangxianzhe/floating-input.nvim) ![](https://img.shields.io/github/last-commit/liangxianzhe/floating-input.nvim) ![](https://img.shields.io/github/commit-activity/y/liangxianzhe/floating-input.nvim)

### Popup

- [nvim-lua/popup.nvim](https://github.com/nvim-lua/popup.nvim) ![](https://img.shields.io/github/stars/nvim-lua/popup.nvim) ![](https://img.shields.io/github/last-commit/nvim-lua/popup.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-lua/popup.nvim)
- [RishabhRD/popfix](https://github.com/RishabhRD/popfix) ![](https://img.shields.io/github/stars/RishabhRD/popfix) ![](https://img.shields.io/github/last-commit/RishabhRD/popfix) ![](https://img.shields.io/github/commit-activity/y/RishabhRD/popfix)
- [javio7/nvim-popcorn](https://github.com/javio7/nvim-popcorn) ![](https://img.shields.io/github/stars/javio7/nvim-popcorn) ![](https://img.shields.io/github/last-commit/javio7/nvim-popcorn) ![](https://img.shields.io/github/commit-activity/y/javio7/nvim-popcorn)

### Animation

- [anuvyklack/animation.nvim](https://github.com/anuvyklack/animation.nvim) ![](https://img.shields.io/github/stars/anuvyklack/animation.nvim) ![](https://img.shields.io/github/last-commit/anuvyklack/animation.nvim) ![](https://img.shields.io/github/commit-activity/y/anuvyklack/animation.nvim)

### FuzzyFinder

- [norcalli/ui.nvim](https://github.com/norcalli/ui.nvim) ![](https://img.shields.io/github/stars/norcalli/ui.nvim) ![](https://img.shields.io/github/last-commit/norcalli/ui.nvim) ![](https://img.shields.io/github/commit-activity/y/norcalli/ui.nvim)

### Spinner

- [javio7/nvim-spinetta](https://github.com/javio7/nvim-spinetta) ![](https://img.shields.io/github/stars/javio7/nvim-spinetta) ![](https://img.shields.io/github/last-commit/javio7/nvim-spinetta) ![](https://img.shields.io/github/commit-activity/y/javio7/nvim-spinetta)

## Error handling

- [uga-rosa/lua-utils.nvim](https://github.com/uga-rosa/lua-utils.nvim) ![](https://img.shields.io/github/stars/uga-rosa/lua-utils.nvim) ![](https://img.shields.io/github/last-commit/uga-rosa/lua-utils.nvim) ![](https://img.shields.io/github/commit-activity/y/uga-rosa/lua-utils.nvim)

## Assert

- [notomo/assertlib.nvim](https://github.com/notomo/assertlib.nvim) ![](https://img.shields.io/github/stars/notomo/assertlib.nvim) ![](https://img.shields.io/github/last-commit/notomo/assertlib.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/assertlib.nvim)

## Time

- [bartek/epochconverter.nvim](https://github.com/bartek/epochconverter.nvim) ![](https://img.shields.io/github/stars/bartek/epochconverter.nvim) ![](https://img.shields.io/github/last-commit/bartek/epochconverter.nvim) ![](https://img.shields.io/github/commit-activity/y/bartek/epochconverter.nvim)

## UUID

- [timwmillard/uuid.nvim](https://github.com/timwmillard/uuid.nvim) ![](https://img.shields.io/github/stars/timwmillard/uuid.nvim) ![](https://img.shields.io/github/last-commit/timwmillard/uuid.nvim) ![](https://img.shields.io/github/commit-activity/y/timwmillard/uuid.nvim)
- [srpmtt/nvim-guid-generator](https://github.com/srpmtt/nvim-guid-generator) ![](https://img.shields.io/github/stars/srpmtt/nvim-guid-generator) ![](https://img.shields.io/github/last-commit/srpmtt/nvim-guid-generator) ![](https://img.shields.io/github/commit-activity/y/srpmtt/nvim-guid-generator)
- [TrevorS/uuid-nvim](https://github.com/TrevorS/uuid-nvim) ![](https://img.shields.io/github/stars/TrevorS/uuid-nvim) ![](https://img.shields.io/github/last-commit/TrevorS/uuid-nvim) ![](https://img.shields.io/github/commit-activity/y/TrevorS/uuid-nvim)
- [danporterhonor/uuid-hex.nvim](https://github.com/danporterhonor/uuid-hex.nvim) ![](https://img.shields.io/github/stars/danporterhonor/uuid-hex.nvim) ![](https://img.shields.io/github/last-commit/danporterhonor/uuid-hex.nvim) ![](https://img.shields.io/github/commit-activity/y/danporterhonor/uuid-hex.nvim)
- [chrsolr/quicky-uuid.nvim](https://github.com/chrsolr/quicky-uuid.nvim) ![](https://img.shields.io/github/stars/chrsolr/quicky-uuid.nvim) ![](https://img.shields.io/github/last-commit/chrsolr/quicky-uuid.nvim) ![](https://img.shields.io/github/commit-activity/y/chrsolr/quicky-uuid.nvim)
- [mubisco/idx.nvim](https://github.com/mubisco/idx.nvim) ![](https://img.shields.io/github/stars/mubisco/idx.nvim) ![](https://img.shields.io/github/last-commit/mubisco/idx.nvim) ![](https://img.shields.io/github/commit-activity/y/mubisco/idx.nvim)

## Net

### HTTP

- [ianjkaplan/hermes.nvim](https://github.com/ianjkaplan/hermes.nvim) ![](https://img.shields.io/github/stars/ianjkaplan/hermes.nvim) ![](https://img.shields.io/github/last-commit/ianjkaplan/hermes.nvim) ![](https://img.shields.io/github/commit-activity/y/ianjkaplan/hermes.nvim)

### Curl

- [javio7/nvim-vurl](https://github.com/javio7/nvim-vurl) ![](https://img.shields.io/github/stars/javio7/nvim-vurl) ![](https://img.shields.io/github/last-commit/javio7/nvim-vurl) ![](https://img.shields.io/github/commit-activity/y/javio7/nvim-vurl)
- [minowak/nvim-curl](https://github.com/minowak/nvim-curl) ![](https://img.shields.io/github/stars/minowak/nvim-curl) ![](https://img.shields.io/github/last-commit/minowak/nvim-curl) ![](https://img.shields.io/github/commit-activity/y/minowak/nvim-curl)

### Hurl

- [samueljoli/hurl.nvim](https://github.com/samueljoli/hurl.nvim) ![](https://img.shields.io/github/stars/samueljoli/hurl.nvim) ![](https://img.shields.io/github/last-commit/samueljoli/hurl.nvim) ![](https://img.shields.io/github/commit-activity/y/samueljoli/hurl.nvim)
- [Zhuxy/hurl.nvim](https://github.com/Zhuxy/hurl.nvim) ![](https://img.shields.io/github/stars/Zhuxy/hurl.nvim) ![](https://img.shields.io/github/last-commit/Zhuxy/hurl.nvim) ![](https://img.shields.io/github/commit-activity/y/Zhuxy/hurl.nvim)
- [jellydn/hurl.nvim](https://github.com/jellydn/hurl.nvim) ![](https://img.shields.io/github/stars/jellydn/hurl.nvim) ![](https://img.shields.io/github/last-commit/jellydn/hurl.nvim) ![](https://img.shields.io/github/commit-activity/y/jellydn/hurl.nvim)

### REST

- [NTBBloodbath/rest.nvim](https://github.com/NTBBloodbath/rest.nvim) ![](https://img.shields.io/github/stars/NTBBloodbath/rest.nvim) ![](https://img.shields.io/github/last-commit/NTBBloodbath/rest.nvim) ![](https://img.shields.io/github/commit-activity/y/NTBBloodbath/rest.nvim)
  - [amirali/rest-ui.nvim](https://github.com/amirali/rest-ui.nvim) ![](https://img.shields.io/github/stars/amirali/rest-ui.nvim) ![](https://img.shields.io/github/last-commit/amirali/rest-ui.nvim) ![](https://img.shields.io/github/commit-activity/y/amirali/rest-ui.nvim)

### GRPC

- [hudclark/grpc-nvim](https://github.com/hudclark/grpc-nvim) ![](https://img.shields.io/github/stars/hudclark/grpc-nvim) ![](https://img.shields.io/github/last-commit/hudclark/grpc-nvim) ![](https://img.shields.io/github/commit-activity/y/hudclark/grpc-nvim)
- [nickkoul/nvim-grpc-explorer](https://github.com/nickkoul/nvim-grpc-explorer) ![](https://img.shields.io/github/stars/nickkoul/nvim-grpc-explorer) ![](https://img.shields.io/github/last-commit/nickkoul/nvim-grpc-explorer) ![](https://img.shields.io/github/commit-activity/y/nickkoul/nvim-grpc-explorer)

### WebSocket

- [rohanorton/ws.nvim](https://github.com/rohanorton/ws.nvim) ![](https://img.shields.io/github/stars/rohanorton/ws.nvim) ![](https://img.shields.io/github/last-commit/rohanorton/ws.nvim) ![](https://img.shields.io/github/commit-activity/y/rohanorton/ws.nvim)
- [iwillreku3206/websocket.nvim](https://github.com/iwillreku3206/websocket.nvim) ![](https://img.shields.io/github/stars/iwillreku3206/websocket.nvim) ![](https://img.shields.io/github/last-commit/iwillreku3206/websocket.nvim) ![](https://img.shields.io/github/commit-activity/y/iwillreku3206/websocket.nvim)

## JSON

- [rxi/json.lua](https://github.com/rxi/json.lua) ![](https://img.shields.io/github/stars/rxi/json.lua) ![](https://img.shields.io/github/last-commit/rxi/json.lua) ![](https://img.shields.io/github/commit-activity/y/rxi/json.lua)
- [Sup3Legacy/json.nvim](https://github.com/Sup3Legacy/json.nvim) ![](https://img.shields.io/github/stars/Sup3Legacy/json.nvim) ![](https://img.shields.io/github/last-commit/Sup3Legacy/json.nvim) ![](https://img.shields.io/github/commit-activity/y/Sup3Legacy/json.nvim)

## Require

- [miversen33/import.nvim](https://github.com/miversen33/import.nvim) ![](https://img.shields.io/github/stars/miversen33/import.nvim) ![](https://img.shields.io/github/last-commit/miversen33/import.nvim) ![](https://img.shields.io/github/commit-activity/y/miversen33/import.nvim)
- [delphinus/lazy_require.nvim](https://github.com/delphinus/lazy_require.nvim) ![](https://img.shields.io/github/stars/delphinus/lazy_require.nvim) ![](https://img.shields.io/github/last-commit/delphinus/lazy_require.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/lazy_require.nvim)

## Hook

- [rktjmp/fwatch.nvim](https://github.com/rktjmp/fwatch.nvim) ![](https://img.shields.io/github/stars/rktjmp/fwatch.nvim) ![](https://img.shields.io/github/last-commit/rktjmp/fwatch.nvim) ![](https://img.shields.io/github/commit-activity/y/rktjmp/fwatch.nvim)
- [notomo/obhook.nvim](https://github.com/notomo/obhook.nvim) ![](https://img.shields.io/github/stars/notomo/obhook.nvim) ![](https://img.shields.io/github/last-commit/notomo/obhook.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/obhook.nvim)

## Mode

- [Iron-E/nvim-libmodal](https://github.com/Iron-E/nvim-libmodal) ![](https://img.shields.io/github/stars/Iron-E/nvim-libmodal) ![](https://img.shields.io/github/last-commit/Iron-E/nvim-libmodal) ![](https://img.shields.io/github/commit-activity/y/Iron-E/nvim-libmodal)

## Buffer

- [matu3ba/libbuf.nvim](https://github.com/matu3ba/libbuf.nvim) ![](https://img.shields.io/github/stars/matu3ba/libbuf.nvim) ![](https://img.shields.io/github/last-commit/matu3ba/libbuf.nvim) ![](https://img.shields.io/github/commit-activity/y/matu3ba/libbuf.nvim)

## Keymap

- [anuvyklack/keymap-layer.nvim](https://github.com/anuvyklack/keymap-layer.nvim) ![](https://img.shields.io/github/stars/anuvyklack/keymap-layer.nvim) ![](https://img.shields.io/github/last-commit/anuvyklack/keymap-layer.nvim) ![](https://img.shields.io/github/commit-activity/y/anuvyklack/keymap-layer.nvim)
- [I60R/map-dsl.nvim](https://github.com/I60R/map-dsl.nvim) ![](https://img.shields.io/github/stars/I60R/map-dsl.nvim) ![](https://img.shields.io/github/last-commit/I60R/map-dsl.nvim) ![](https://img.shields.io/github/commit-activity/y/I60R/map-dsl.nvim)
- [notomo/listdefined.nvim](https://github.com/notomo/listdefined.nvim) ![](https://img.shields.io/github/stars/notomo/listdefined.nvim) ![](https://img.shields.io/github/last-commit/notomo/listdefined.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/listdefined.nvim)
- [Nexmean/caskey.nvim](https://github.com/Nexmean/caskey.nvim) ![](https://img.shields.io/github/stars/Nexmean/caskey.nvim) ![](https://img.shields.io/github/last-commit/Nexmean/caskey.nvim) ![](https://img.shields.io/github/commit-activity/y/Nexmean/caskey.nvim)
- [jake-stewart/normon.nvim](https://github.com/jake-stewart/normon.nvim) ![](https://img.shields.io/github/stars/jake-stewart/normon.nvim) ![](https://img.shields.io/github/last-commit/jake-stewart/normon.nvim) ![](https://img.shields.io/github/commit-activity/y/jake-stewart/normon.nvim)
- [CrispyBaccoon/keymaps.nvim](https://github.com/CrispyBaccoon/keymaps.nvim) ![](https://img.shields.io/github/stars/CrispyBaccoon/keymaps.nvim) ![](https://img.shields.io/github/last-commit/CrispyBaccoon/keymaps.nvim) ![](https://img.shields.io/github/commit-activity/y/CrispyBaccoon/keymaps.nvim)
- [kamalsacranie/nvim-mapper](https://github.com/kamalsacranie/nvim-mapper) ![](https://img.shields.io/github/stars/kamalsacranie/nvim-mapper) ![](https://img.shields.io/github/last-commit/kamalsacranie/nvim-mapper) ![](https://img.shields.io/github/commit-activity/y/kamalsacranie/nvim-mapper)

## autocmd

- [mvllow/matcha.nvim](https://github.com/mvllow/matcha.nvim) ![](https://img.shields.io/github/stars/mvllow/matcha.nvim) ![](https://img.shields.io/github/last-commit/mvllow/matcha.nvim) ![](https://img.shields.io/github/commit-activity/y/mvllow/matcha.nvim)
- [CWood-sdf/future.nvim](https://github.com/CWood-sdf/future.nvim) ![](https://img.shields.io/github/stars/CWood-sdf/future.nvim) ![](https://img.shields.io/github/last-commit/CWood-sdf/future.nvim) ![](https://img.shields.io/github/commit-activity/y/CWood-sdf/future.nvim)

## Color

- [oleksiiluchnikov/gradient.nvim](https://github.com/oleksiiluchnikov/gradient.nvim) ![](https://img.shields.io/github/stars/oleksiiluchnikov/gradient.nvim) ![](https://img.shields.io/github/last-commit/oleksiiluchnikov/gradient.nvim) ![](https://img.shields.io/github/commit-activity/y/oleksiiluchnikov/gradient.nvim)
- [loganswartz/polychrome.nvim](https://github.com/loganswartz/polychrome.nvim) ![](https://img.shields.io/github/stars/loganswartz/polychrome.nvim) ![](https://img.shields.io/github/last-commit/loganswartz/polychrome.nvim) ![](https://img.shields.io/github/commit-activity/y/loganswartz/polychrome.nvim)

## Icon

- [kyazdani42/nvim-web-devicons](https://github.com/kyazdani42/nvim-web-devicons) ![](https://img.shields.io/github/stars/kyazdani42/nvim-web-devicons) ![](https://img.shields.io/github/last-commit/kyazdani42/nvim-web-devicons) ![](https://img.shields.io/github/commit-activity/y/kyazdani42/nvim-web-devicons)
  - [projekt0n/circles.nvim](https://github.com/projekt0n/circles.nvim) ![](https://img.shields.io/github/stars/projekt0n/circles.nvim) ![](https://img.shields.io/github/last-commit/projekt0n/circles.nvim) ![](https://img.shields.io/github/commit-activity/y/projekt0n/circles.nvim)
- [yamatsum/nvim-nonicons](https://github.com/yamatsum/nvim-nonicons) ![](https://img.shields.io/github/stars/yamatsum/nvim-nonicons) ![](https://img.shields.io/github/last-commit/yamatsum/nvim-nonicons) ![](https://img.shields.io/github/commit-activity/y/yamatsum/nvim-nonicons)
- [mortepau/codicons.nvim](https://github.com/mortepau/codicons.nvim) ![](https://img.shields.io/github/stars/mortepau/codicons.nvim) ![](https://img.shields.io/github/last-commit/mortepau/codicons.nvim) ![](https://img.shields.io/github/commit-activity/y/mortepau/codicons.nvim)
- [DaikyXendo/nvim-material-icon](https://github.com/DaikyXendo/nvim-material-icon) ![](https://img.shields.io/github/stars/DaikyXendo/nvim-material-icon) ![](https://img.shields.io/github/last-commit/DaikyXendo/nvim-material-icon) ![](https://img.shields.io/github/commit-activity/y/DaikyXendo/nvim-material-icon)
- [mskelton/termicons.nvim](https://github.com/mskelton/termicons.nvim) ![](https://img.shields.io/github/stars/mskelton/termicons.nvim) ![](https://img.shields.io/github/last-commit/mskelton/termicons.nvim) ![](https://img.shields.io/github/commit-activity/y/mskelton/termicons.nvim)

## Date

- [oleksiiluchnikov/dates.nvim](https://github.com/oleksiiluchnikov/dates.nvim) ![](https://img.shields.io/github/stars/oleksiiluchnikov/dates.nvim) ![](https://img.shields.io/github/last-commit/oleksiiluchnikov/dates.nvim) ![](https://img.shields.io/github/commit-activity/y/oleksiiluchnikov/dates.nvim)

## Unicode

- [uga-rosa/utf8.nvim](https://github.com/uga-rosa/utf8.nvim) ![](https://img.shields.io/github/stars/uga-rosa/utf8.nvim) ![](https://img.shields.io/github/last-commit/uga-rosa/utf8.nvim) ![](https://img.shields.io/github/commit-activity/y/uga-rosa/utf8.nvim)

## random variable names

- [ghidalgo93/boring_wozniak.nvim](https://github.com/ghidalgo93/boring_wozniak.nvim) ![](https://img.shields.io/github/stars/ghidalgo93/boring_wozniak.nvim) ![](https://img.shields.io/github/last-commit/ghidalgo93/boring_wozniak.nvim) ![](https://img.shields.io/github/commit-activity/y/ghidalgo93/boring_wozniak.nvim)

## Mathematics

- [jbyuki/swan.lua](https://github.com/jbyuki/swan.lua) ![](https://img.shields.io/github/stars/jbyuki/swan.lua) ![](https://img.shields.io/github/last-commit/jbyuki/swan.lua) ![](https://img.shields.io/github/commit-activity/y/jbyuki/swan.lua)

## Treesitter

- [tjdevries/tree-sitter-lua](https://github.com/tjdevries/tree-sitter-lua) ![](https://img.shields.io/github/stars/tjdevries/tree-sitter-lua) ![](https://img.shields.io/github/last-commit/tjdevries/tree-sitter-lua) ![](https://img.shields.io/github/commit-activity/y/tjdevries/tree-sitter-lua)

## Enhanced Standard Features

- [delphinus/f_meta.nvim](https://github.com/delphinus/f_meta.nvim) ![](https://img.shields.io/github/stars/delphinus/f_meta.nvim) ![](https://img.shields.io/github/last-commit/delphinus/f_meta.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/f_meta.nvim)

## Util wrapper

- [nvim-lua/plenary.nvim](https://github.com/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/stars/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/last-commit/nvim-lua/plenary.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-lua/plenary.nvim)
- [anuvyklack/nvim-api-wrappers](https://github.com/anuvyklack/nvim-api-wrappers) ![](https://img.shields.io/github/stars/anuvyklack/nvim-api-wrappers) ![](https://img.shields.io/github/last-commit/anuvyklack/nvim-api-wrappers) ![](https://img.shields.io/github/commit-activity/y/anuvyklack/nvim-api-wrappers)
- [javio7/nvim-osfa](https://github.com/javio7/nvim-osfa) ![](https://img.shields.io/github/stars/javio7/nvim-osfa) ![](https://img.shields.io/github/last-commit/javio7/nvim-osfa) ![](https://img.shields.io/github/commit-activity/y/javio7/nvim-osfa)
- [DrKGD/deatharte.api.nvim](https://github.com/DrKGD/deatharte.api.nvim) ![](https://img.shields.io/github/stars/DrKGD/deatharte.api.nvim) ![](https://img.shields.io/github/last-commit/DrKGD/deatharte.api.nvim) ![](https://img.shields.io/github/commit-activity/y/DrKGD/deatharte.api.nvim)
- [tenxsoydev/nx.nvim](https://github.com/tenxsoydev/nx.nvim) ![](https://img.shields.io/github/stars/tenxsoydev/nx.nvim) ![](https://img.shields.io/github/last-commit/tenxsoydev/nx.nvim) ![](https://img.shields.io/github/commit-activity/y/tenxsoydev/nx.nvim)
- [ollbx/nvim-utility-lib.nvim](https://github.com/ollbx/nvim-utility-lib.nvim) ![](https://img.shields.io/github/stars/ollbx/nvim-utility-lib.nvim) ![](https://img.shields.io/github/last-commit/ollbx/nvim-utility-lib.nvim) ![](https://img.shields.io/github/commit-activity/y/ollbx/nvim-utility-lib.nvim)
- [wrightjjw/cool.nvim](https://github.com/wrightjjw/cool.nvim) ![](https://img.shields.io/github/stars/wrightjjw/cool.nvim) ![](https://img.shields.io/github/last-commit/wrightjjw/cool.nvim) ![](https://img.shields.io/github/commit-activity/y/wrightjjw/cool.nvim)
- [linrongbin16/commons.nvim](https://github.com/linrongbin16/commons.nvim) ![](https://img.shields.io/github/stars/linrongbin16/commons.nvim) ![](https://img.shields.io/github/last-commit/linrongbin16/commons.nvim) ![](https://img.shields.io/github/commit-activity/y/linrongbin16/commons.nvim)
- [nvim-neorg/lua-utils.nvim](https://github.com/nvim-neorg/lua-utils.nvim) ![](https://img.shields.io/github/stars/nvim-neorg/lua-utils.nvim) ![](https://img.shields.io/github/last-commit/nvim-neorg/lua-utils.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-neorg/lua-utils.nvim)
